@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: turba/data.php,v 1.70.4.17 2008/06/13 08:40:03 jan Exp $
+ * $Horde: turba/data.php,v 1.70.4.20 2008/08/11 12:50:18 jan Exp $
  *
  * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
  *
@@ -42,10 +42,11 @@ function _emptyAttributeFilter($var)
  * Static function to make a given email address rfc822 compliant.
  *
  * @param string $address  An email address.
+ * @param boolean $allow_multi  Allow multiple email addresses.
  *
  * @return string  The RFC822-formatted email address.
  */
-function _getBareEmail($address)
+function _getBareEmail($address, $allow_multi = false)
 {
     // Empty values are still empty.
     if (!$address) {
@@ -60,12 +61,26 @@ function _getBareEmail($address)
         $rfc822 = new Mail_RFC822();
     }
 
-    $rfc822->validateMailbox($address);
-    return MIME::rfc822WriteAddress($address->mailbox, $address->host);
+    // Split multiple email addresses
+    if ($allow_multi) {
+        $addrs = MIME::rfc822Explode($address);
+    } else {
+        $addrs = array($address);
+    }
+
+    $result = array();
+    foreach ($addrs as $addr) {
+        $addr = trim($addr);
+
+        if ($rfc822->validateMailbox($addr)) {
+            $result[] = MIME::rfc822WriteAddress($addr->mailbox, $addr->host);
+        }
+    }
+
+    return implode(', ', $result);
 }
 
-@define('TURBA_BASE', dirname(__FILE__));
-require_once TURBA_BASE . '/lib/base.php';
+require_once dirname(__FILE__) . '/lib/base.php';
 require_once 'Horde/Data.php';
 
 if (!$conf['menu']['import_export']) {
@@ -107,6 +122,48 @@ $app_fields = array();
 $time_fields = array();
 $error = false;
 $outlook_mapping = array(
+    'Title' => 'namePrefix',
+    'First Name' => 'firstname',
+    'Middle Name' => 'middlenames',
+    'Last Name' => 'lastname',
+    'Nickname' => 'nickname',
+    'Suffix' => 'nameSuffix',
+    'Company' => 'company',
+    'Department' => 'department',
+    'Job Title' => 'title',
+    'Business Street' => 'workStreet',
+    'Business City' => 'workCity',
+    'Business State' => 'workProvince',
+    'Business Postal Code' => 'workPostalCode',
+    'Business Country' => 'workCountry',
+    'Home Street' => 'homeStreet',
+    'Home City' => 'homeCity',
+    'Home State' => 'homeProvince',
+    'Home Postal Code' => 'homePostalCode',
+    'Home Country' => 'homeCountry',
+    'Business Fax' => 'workFax',
+    'Business Phone' => 'workPhone',
+    'Home Phone' => 'homePhone',
+    'Mobile Phone' => 'cellPhone',
+    'Pager' => 'pager',
+    'Anniversary' => 'anniversary',
+    'Assistant\'s Name' => 'assistant',
+    'Birthday' => 'birthday',
+    'Business Address PO Box' => 'workPOBox',
+    'Categories' => 'category',
+    'Children' => 'children',
+    'E-mail Address' => 'email',
+    'Home Address PO Box' => 'homePOBox',
+    'Initials' => 'initials',
+    'Internet Free Busy' => 'freebusyUrl',
+    'Language' => 'language',
+    'Notes' => 'notes',
+    'Profession' => 'role',
+    'Office Location' => 'office',
+    'Spouse' => 'spouse',
+    'Web Page' => 'website',
+);
+$import_mapping = array(
     'e-mail' => 'email',
     'homeaddress' => 'homeAddress',
     'businessaddress' => 'workAddress',
@@ -116,10 +173,41 @@ $outlook_mapping = array(
     'businessfax' => 'fax',
     'jobtitle' => 'title',
     'internetfreebusy' => 'freebusyUrl',
-    );
+
+    // Entourage on MacOS
+    'Dept' => 'department',
+    'Work Street Address' => 'workStreet',
+    'Work City' => 'workCity',
+    'Work State' => 'workProvince',
+    'Work Zip' => 'workPostalCode',
+    'Work Country/Region' => 'workCountry',
+    'Home Street Address' => 'homeStreet',
+    'Home City' => 'homeCity',
+    'Home State' => 'homeProvince',
+    'Home Zip' => 'homePostalCode',
+    'Home Country/Region' => 'homeCountry',
+    'Work Fax' => 'workFax',
+    'Work Phone 1' => 'workPhone',
+    'Home Phone 1' => 'homePhone',
+    'Instant Messaging 1' => 'instantMessenger',
+
+    // Thunderbird
+    'Primary Email' => 'email',
+    'Fax Number' => 'fax',
+    'Pager Number' => 'pager',
+    'Mobile Number' => 'Mobile Phone',
+    'Home Address' => 'homeStreet',
+    'Home ZipCode' => 'homePostalCode',
+    'Work Address' => 'workStreet',
+    'Work ZipCode' => 'workPostalCode',
+    'Work Country' => 'workCountry',
+    'Work Phone' => 'workPhone',
+    'Organization' => 'company',
+    'Web Page 1' => 'website',
+);
 $param = array('time_fields' => $time_fields,
                'file_types'  => $file_types,
-               'import_mapping' => $outlook_mapping);
+               'import_mapping' => array_merge($outlook_mapping, $import_mapping));
 $import_format = Util::getFormData('import_format', '');
 if ($import_format == 'mulberry' || $import_format == 'pine') {
     $import_format = 'tsv';
@@ -364,12 +452,15 @@ if (is_array($next_step)) {
             } elseif ($result->count()) {
                 $result->reset();
                 $object = $result->next();
-                $notification->push(sprintf(_("\"%s\" already exists and was not imported."), $object->getValue('name')), 'horde.message');
+                $notification->push(sprintf(_("\"%s\" already exists and was not imported."),
+                                            $object->getValue('name')), 'horde.message');
             } else {
                 /* Check for, and validate, any email fields */
                 foreach (array_keys($row) as $field) {
                     if ($attributes[$field]['type'] == 'email') {
-                        $row[$field] = _getBareEmail($row[$field]);
+                        $allow_multi = is_array($attributes[$field]['params']) &&
+                            !empty($attributes[$field]['params']['allow_multi']);
+                        $row[$field] = _getBareEmail($row[$field], $allow_multi);
                     }
                 }
                 $row['__owner'] = $driver->getContactOwner();
