@@ -3,7 +3,7 @@
  * The Turba_ListView:: class provides an interface for objects that
  * visualize Turba_lists.
  *
- * $Horde: turba/lib/ListView.php,v 1.17.10.19 2008/04/24 03:42:56 mrubinsk Exp $
+ * $Horde: turba/lib/ListView.php,v 1.17.10.21 2008/07/20 08:01:45 jan Exp $
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@csh.rit.edu>
@@ -305,7 +305,7 @@ class Turba_ListView {
      */
     function getSortInfoForColumn($i)
     {
-        $sortorder = Turba::getPreferredSortOrder($this->columns);
+        $sortorder = Turba::getPreferredSortOrder();
         $column_name = $this->getColumnName($i);
         $i = 0;
         foreach ($sortorder as $sortfield) {
@@ -337,7 +337,7 @@ class Turba_ListView {
     function getSortOrderDescription()
     {
         $description = array();
-        $sortorder = Turba::getPreferredSortOrder($this->columns);
+        $sortorder = Turba::getPreferredSortOrder();
         foreach ($sortorder as $elt) {
             $field = $elt['field'];
             if ($field == 'lastname') {
@@ -389,6 +389,7 @@ class Turba_ListView {
     {
         ob_start();
         $width = floor(90 / (count($this->columns) + 1));
+        @list($own_source, $own_id) = explode(';', $GLOBALS['prefs']->getValue('own_contact'));
 
         include TURBA_TEMPLATES . '/browse/column_headers.inc';
 
